/* LocaleInformation_pl.java --
   Copyright (C) 2004  Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


// This file was automatically generated by gnu.localegen from LDML

package gnu.java.locale;

import java.util.Enumeration;
import java.util.Hashtable;
import java.util.StringTokenizer;
import java.util.ListResourceBundle;

public class LocaleInformation_pl extends ListResourceBundle
{
  private static final String currenciesDisplayNameKeys = "JOD|BOV|XAU|FOK|LBP|EUR|VND|TZS|BOP|KHR|XAM|BOL|KHO|ZMP|AUP|XAF|MTP|GHR|ZMK|XAD|GHP|BOB|GHO|MTL|AUD|ITL|GHC|SGD|PAB|LAK|KGS|CHF|ATS|USD|ETD|BND|JMP|ETB|DZF|DZD|PYG|LYP|JMD|ISK|ESP|BMP|LYD|LYB|BMD|NLG|MRO|IRR|SEK|ERN|KES|CFF|ARS|ARP|ARM|TWD|SDP|GEL|GEK|MQF|FKP|ARA|SDD|IQD|TVD|SCR|LVR|FJP|LVL|CDL|CDG|CDF|FJD|NIO|MOP|NIG|NIC|XTR|FIN|FIM|SBD|LUF|TTO|AOS|AOR|MNT|HUF|BIF|AON|AOK|TTD|SZL|GBP|SAS|SAR|LTT|INR|PTE|AOA|PTC|LTL|KZT|KZR|VGD|NGP|MMX|NGN|HTG|SYP|PSP|BHD|MMK|ANG|CZK|IMP|BGX|LSL|GAF|BGO|BGN|BGM|CAD|BGL|TRL|KYD|CYP|ILS|GYD|AMD|ILP|MLF|ILL|VEB|ALX|LRD|ALV|HRK|REF|HRD|ALL|JEP|ALK|MKN|VDP|VDN|MKD|VDD|TPP|XPF|BEL|GWP|KWD|BEF|TPE|BEC|GWE|SVC|CWG|BDT|TOS|TOP|XOF|SUR|SUN|NCF|CVE|XNF|ZAR|DOP|CUX|ZAP|ZAL|TND|CUP|UGX|LNR|AIF|VAL|STE|UGS|STD|MHD|NZP|WST|WSP|HNL|XMF|TMM|GTQ|NZD|SSP|BBD|NAD|MGF|MGA|EGP|BZH|PLZ|BAN|PLX|BAM|BZD|BAD|PLN|YER|SRG|CSK|KRW|BYR|YEI|BYL|CSC|KRO|KRH|BYB|SQS|GRN|PKR|AFN|ZWD|LKR|GRD|IEP|AFA|YDD|RWF|CRC|TJS|TJR|EEK|GQP|MDR|HKD|DKK|MDL|GQF|GQE|IDR|AED|KPW|IDN|BWP|MDC|IDJ|KPP|IDG|VUV|XID|SOS|ADP|RUR|GPF|DJF|ADD|MCG|MCF|ECS|LIF|RUB|PHP|UZS|COP|THB|IBP|BUR|COF|BUK|COB|UZC|UAK|QAR|UAH|GNS|CNY|MZM|CNX|UYU|GNI|SML|MZE|CNP|GNF|PGK|OMS|OMR|UYP|XFU|BTR|ZRZ|MAF|MAD|BTN|XFO|UYF|MYR|ZRN|AZM|GMP|KMF|SLL|GMD|BSP|CMF|XEF|BSD|MXP|MXN|PES|GLK|BRZ|PEN|CLP|SKK|PEI|BRR|XDR|FRF|BRN|CLE|BRL|CLC|BRE|MWP|BRC|BRB|MWK|PDR|DEM|TDF|PDN|PDK|NPR|CKD|JPY|MVR|XCF|MVP|XCD|SIT|YUR|AWG|YUO|DDM|YUN|YUM|TCC|YUG|YUF|RON|YUD|ROL|SIB|NOK|MUR|GIP|VNS|VNR|KID|SHP|VNN";

  private static final String currenciesDisplayNameValues = "dinar jorda\u0144ski|mvdol boliwijski|z\u0142oto|korona Wysp Owczych|funt liba\u0144ski|euro|dong wietnamski|szyling tanza\u0144ski|peso boliwijskie|riel kambod\u017ca\u0144ski|jednostka monetarna azjatycka|boliviano (1863-1962)|stary riel kambod\u017ca\u0144ski|funt zambijski|funt australijski|frank CFA BEAC|funt malta\u0144ski|cedi zrewaloryzowane gha\u0144skie|kwacha zambijska|jednostla dinar rozliczeniowy azjatycki|funt gha\u0144ski|boliviano|stare cedi gha\u0144skie|lira malta\u0144ska|dolar australijski|lir w\u0142oski|cedi gha\u0144skie|dolar singapurski|balboa panamski|kip laota\u0144ski|som kirgiski|frank szwajcarski|szyling austriacki\u00a0|dolar ameryka\u0144ski\u00a0|dolar etiopski|dolar brunejski|funt  jamajski|birr etiopski|nowy frank algierski|dinar algierski|guarani paragwajskie|funt libijski|dolar jamajski|korona islandzka|peseta hiszpa\u0144ska|funt bermudzki|dinar libijski|lir brytyjskich w\u0142adz wojskowych w Libii|dolar bermudzki|gulden holenderski\u00a0|ouguiya mautera\u0144ska|rial ira\u0144ski|korona szwedzka|nakfa erytrejska|szyling kenijski|frank CFA Republiki \u015arodkowoafryka\u0144skiej|peso argenty\u0144skie|peso argenty\u0144skie (1983-1985)|peso argenty\u0144skie Moneda Nacional|nowy dolar tajwa\u0144ski|funt suda\u0144ski|lari gruzi\u0144skie|Larit gruzi\u0144ski kupon|frank Martynika|funt Wysp Falklandzkich|austral argenty\u0144ski|dinar suda\u0144ski|dinar iracki|dolar Tuvalu|rupia seszelska|rubel \u0142otewski|funt fid\u017cijski|\u0142at \u0142otewski|zair kongijski|frank Republiki Konga|frank kongijski|dolar fid\u017cijski|cordoba oro nikaragua\u0144ska|pataka Macao|cordoba Gold nikaragua\u0144ska|cordoba nikaragua\u0144ska|rubel transferowy COMECON|marka fi\u0144ska (1860-1962)|marka fi\u0144ska|dolar Wysp Salomona|frank luksemburski|stary dolar Trynidadu i Tobago|escudo angola\u0144skie|kwanza angola\u0144ska Reajustado (1995-1999)|tugrik mongolski|forint w\u0119gierski\u00a0|frank burundyjski|nowa kwanza angola\u0144ska (1990-2000)|kwanza angola\u0144ska (1977-1990)|dolar Trynidadu i Tobago|lilangeni Suazi|funt szterling|riyal sovereign saudyjski|rial saudyjski|talon litewski|rupia indyjska|escudo portugalskie|kwanza angola\u0144ska|conto portugalskie|lit litewski|Tenge kazachskie|rubel kazachski|dolar Brytyjskich Wysp Dziewiczych|funt nigeryjski|dolarowy certyfikat Myanmar dla transakcji zagranicznych|naira nigeryjska|gourde haita\u0144skie|funt syryjski|funt palesty\u0144ski|dinar bahra\u0144ski|kyat Myanmar|gulden Antyle Holenderskie|korona czeska|funt szterling Wyspa Man|lewa bu\u0142garskie dewizowe dla transakcji zagranicznych|loti Lesoto|frank CFA Gabonu|lewa bu\u0142garskie (1879-1952)|nowe lewa bu\u0142garskie|lewa bu\u0142garskie socjalistyczne|dolar kanadyjski|lewa bu\u0142garskie|lir turecki|dolar kajma\u0144ski|funt cypryjski|nowy szekel izraelski|dolar guja\u0144ski|dram arme\u0144ski|funt izraelski|frank malijski|szekel izraelski|boliwar wenezuelski|dolar alba\u0144ski dewizowy dla transakcji zagranicznych|dolar liberyjski|lek waluta alba\u0144ska|kuna chorwacka|frank Reunion|dinar chorwacki|lek alba\u0144ski|funt szterling Jersey|lek alba\u0144ski (1946-1961)|denar macedo\u0144ski (1992-1993)|viet minh piastre dong viet p\u00f3\u0142nocnowietnamski|nowy dong p\u00f3\u0142nocnowietnamski|denar macedo\u0144ski|piastre dong viet p\u00f3\u0142nocnowietnamski|pataca timorskie|frank CFP|frank belgijski (finansowy)|peso Guinea-Bissau|dinar kuwejcki|frank belgijski|escudo timorskie|frank belgijski (zamienny)|escudo Gwinea Portugalska|colon salwadorski|gulden Curacao|taka bengalska|funt szterling Tonga|pa\u02bbanga Tonga|frank CFA|rubel radziecki|nowy rubel radziecki|franc germinal Nowa Kaledonia|escudo Zielonego Przyl\u0105dka|frank CFA Antyli Francuskich|rand po\u0142udniowoafryka\u0144ski|peso dominika\u0144skie|certyfikaty kuba\u0144skie dla transakcji zagranicznych|funt po\u0142udniowoafryka\u0144ski|rand po\u0142udniowoafryka\u0144ski (finansowy)|dinar tunezyjski|peso kuba\u0144skie|szyling ugandyjski|rupia cejlo\u0144ska|frank Affars and Issas Franc|lir Miasta Watykan|escudo Wysp \u015awi\u0119tego Tomasza i\u00a0Ksi\u0105\u017c\u0119cej|szyling ugandyjski (1966-1987)|dobra Wysp \u015awi\u0119tego Tomasza i\u00a0Ksi\u0105\u017c\u0119cej|dolar Wysp Marshalla|funt nowozelandzki|tala samoa\u0144ska|funt samoa\u0144ski|lempira Hondurasu|nowy frank Metropolii Francuskiej|manat turkme\u0144ski|quetzal gwatemalski|dolar nowozelandzki|funt szkocki|dolar Barbadosu|dolar namibijski|frank malgaski|ariar malgaski|funt egipski|dolar Hondurasu Brytyjskiego|z\u0142oty polski (1950-1995)|nowy dinar Bo\u015bni i Hercegowinyr|z\u0142oty polski dewizowy dla transakcji zagranicznych|marka konwertybilna Bo\u015bni i Hercegowiny|dolar belize\u0144ski|dinar Bo\u015bni i Hercegowiny|z\u0142oty polski|rial jeme\u0144ski|gulden surinamski|korona czechos\u0142owacka|won po\u0142udniowokorea\u0144ski|rubel bia\u0142oruski|riyal Imadi jeme\u0144ski|rubel bia\u0142oruski (1992-1994)|korona czechos\u0142owacka|stary won po\u0142udniowokorea\u0144ski|hwan po\u0142udniowokorea\u0144ski|rubel bia\u0142oruski (1994-1999)|szyling somalijski|nowa drachma grecka|rupia pakista\u0144ska|afgani|dolar Zimbabwe|rupia lankijska|drachma grecka|funt irlandzki|afgani (1927-2002)|dinar jeme\u0144ski|frank ruandyjski|colon kostaryka\u0144ski|somoni tad\u017cyckie|rubel tad\u017cycki|korona esto\u0144ska|peseta guja\u0144ska Gwinei R\u00f3wnikowej|rubel kuponowy mo\u0142dawski|dolar hongko\u0144ski|korona du\u0144ska|lej mo\u0142dawski|frank Gwinei R\u00f3wnikowej|ekwele gwinejskie Gwinei R\u00f3wnikowej|rupia indonezyjska|dirham ZEA|won p\u00f3\u0142nocnokorea\u0144ski|nowa rupia indonezyjska|pula|lej kuponowy mo\u0142dawski|rupia indonezyjska Java|won ludowop\u00f3\u0142nocnokorea\u0144ski|gulden indonezyjski Nica|vatu Vanuatu|dinar islamski|szyling somalijski|peseta andorska|rubel rosyjski (1991-1998)|frank Gwadelupy|frank D\u017cibuti|diner andorski|frank Monaco Germinal|nowy frank Monaco|sucre ekwadorski|frank Liechtenstein|rubel rosyjski|peso filipi\u0144skie|som uzbecki|peso kolumbijskie|baht tajski|fund p\u00f3\u0142nocnoirlandzki|rupia birma\u0144ska|frank CFA Konga|kyat birma\u0144ski|peso kolumbijskie papierowe|som kuponowy uzbecki|karbowaniec ukrai\u0144ski|rial katarski|hrywna ukrai\u0144ska|syli gwinejskie|juan renminbi|metical Mozambik|dolar chi\u0144ski dla transakcji zagranicznych|peso urugwajskie|frank gwinejski (1960-1972)|lir San Marino|escudo mozambickie|Jen Min Piao juan Jen Min Piao chi\u0144ski|frank gwinejski|kina Papua Nowa Gwinea|rial saidi oma\u0144ski|rial Omanu|peso urugwajskie (1975-1993)|UIC-frank francuski|rupia Bhutan|zair zairski|frank maroka\u0144ski|dirham maroka\u0144ski|ngultrum  Bhutan|frank z\u0142oty francuski|peso urugwajskie Fuerte|ringgit malezyjski|nowy zair zairski|manat azerbejd\u017ca\u0144ski|funt gambijski|frank komoryjski|leone Sierra Leone|dalasi gambijskie|funt bahamski|frank CFA Kamerunu|frank CFA BCEAEC|dolar bahamski|peso srebrne meksyka\u0144skie (1861-1992)|peso meksyka\u0144skie|sol peruwia\u0144ski|korona grenlandzka|cruzeiro brazylijskie (1942-1967)|nowy sol peruwia\u0144ski|peso chilijskie|korona s\u0142owacka|inti peruwia\u0144ski|cruzeiro brazylijskie|specjalne prawa ci\u0105gnienia|frank francuski\u00a0|cruzado brazylijskie|escudo chilijskie|real brazylijski|condor chilijski|cruzeiro brazylijskie(1990-1993)|funt malawski|cruzado brazylijskie|cruzeiro novo brazylijskie (1967-1986)|kwacha malawska|rubel naddniestrza\u0144ski|marka niemiecka|frank CFA Czadu|nowy rubel naddniestrza\u0144ski|rubel kuponowy naddniestrza\u0144ski|rupia nepalska|dolar Wysp Cooka|jen japo\u0144ski|rufiyaa malediwska|nowy frank CFA|rupia malediwska|dolar wschodniokaraibski|tolar s\u0142owe\u0144ski|dinar reformowany jugos\u0142awia\u0144ski|gulden arubski|dinar pa\u017adziernikowy jugos\u0142awia\u0144ski|wschodnia marka wschodnioniemiecka|dinar jugos\u0142awia\u0144ski wymienny|nowy dinar jugos\u0142awia\u0144ski|korona Turks i Caicos|dinar jugos\u0142awia\u0144ski 1994|dinar Federacji jugos\u0142awia\u0144skiej|nowy lej rumu\u0144ski|dinar jugos\u0142awia\u0144ski wymienny|lej rumu\u0144ski|tolar s\u0142owe\u0144ski bonowy|korona norweska|rupia Mauritius|funt gibraltarski|dong narodowy wietnamski|dong Republiki Wietnamskiej|dolar Kiribati|funt Wyspy \u015awi\u0119tej Heleny|nowy dong wietnamski";

  private static final Hashtable currenciesDisplayName;
  static
  {
    currenciesDisplayName = new Hashtable();
    Enumeration keys = new StringTokenizer(currenciesDisplayNameKeys, "|");
    Enumeration values = new StringTokenizer(currenciesDisplayNameValues, "|");
    while (keys.hasMoreElements())
      {
         String key = (String) keys.nextElement();
         String value = (String) values.nextElement();
         currenciesDisplayName.put(key, value);
      }
  }

  private static final String currenciesSymbolKeys = "JOD|BOV|XAU|FOK|LBP|VND|TZS|BOP|KHR|XAM|BOL|KHO|ZMP|AUP|XAF|MTP|GHR|ZMK|XAD|GHP|BOB|GHO|MTL|AUD|GHC|SGD|PAB|LAK|KGS|CHF|ATS|USD|ETD|BND|JMP|ETB|DZF|DZD|PYG|LYP|JMD|ISK|ESP|BMP|LYD|LYB|BMD|NLG|MRO|IRR|SEK|ERN|KES|CFF|ARS|ARP|ARM|TWD|SDP|GEL|GEK|MQF|FKP|ARA|SDD|IQD|TVD|SCR|LVR|FJP|LVL|CDL|CDG|CDF|FJD|NIO|MOP|NIG|NIC|XTR|FIN|FIM|SBD|LUF|TTO|AOS|AOR|MNT|HUF|BIF|AON|AOK|TTD|SZL|SAS|SAR|LTT|INR|PTE|AOA|PTC|LTL|KZT|KZR|VGD|NGP|MMX|NGN|HTG|SYP|PSP|BHD|MMK|ANG|CZK|IMP|BGX|LSL|GAF|BGO|BGN|BGM|CAD|BGL|TRL|KYD|CYP|ILS|GYD|AMD|ILP|MLF|ILL|VEB|ALX|LRD|ALV|HRK|REF|HRD|ALL|JEP|ALK|MKN|VDP|VDN|MKD|VDD|TPP|XPF|BEL|GWP|KWD|BEF|TPE|BEC|GWE|SVC|CWG|BDT|TOS|TOP|XOF|SUR|SUN|NCF|CVE|XNF|ZAR|DOP|CUX|ZAP|ZAL|TND|CUP|UGX|LNR|AIF|VAL|STE|UGS|STD|MHD|NZP|WST|WSP|HNL|XMF|TMM|GTQ|NZD|SSP|BBD|NAD|MGF|MGA|EGP|BZH|PLZ|BAN|PLX|BAM|BZD|BAD|PLN|YER|SRG|CSK|KRW|BYR|YEI|BYL|CSC|KRO|KRH|BYB|SQS|GRN|PKR|AFN|ZWD|LKR|GRD|IEP|AFA|YDD|RWF|CRC|TJS|TJR|EEK|GQP|MDR|HKD|DKK|MDL|GQF|GQE|IDR|AED|KPW|IDN|BWP|MDC|IDJ|KPP|IDG|VUV|XID|SOS|ADP|RUR|GPF|DJF|ADD|MCG|MCF|ECS|LIF|RUB|PHP|UZS|COP|THB|IBP|BUR|COF|BUK|COB|UZC|UAK|QAR|UAH|GNS|CNY|MZM|CNX|UYU|GNI|SML|MZE|CNP|PGK|OMS|GNF|UYP|OMR|XFU|BTR|ZRZ|MAF|MAD|BTN|XFO|UYF|MYR|ZRN|AZM|GMP|KMF|SLL|GMD|BSP|CMF|XEF|BSD|MXP|MXN|PES|GLK|BRZ|PEN|CLP|SKK|PEI|BRR|XDR|FRF|BRN|CLE|BRL|CLC|BRE|MWP|BRC|BRB|MWK|PDR|DEM|TDF|PDN|PDK|NPR|CKD|MVR|XCF|MVP|XCD|SIT|YUR|AWG|YUO|DDM|YUN|YUM|TCC|YUG|YUF|RON|YUD|ROL|SIB|NOK|MUR|GIP|VNS|VNR|KID|SHP|VNN";

  private static final String currenciesSymbolValues = "JD|BOV|XAU|FOK|LL|VND|T Sh|BOP|CR|XAM|BOL|KHO|ZMP|AUP|XAF|MTP|GHR|ZMK|XAD|GHP|Bs|GHO|Lm|$A|GHC|S$|PAB|LAK|som|SwF|ATS|US$|ETD|BND|JMP|Br|DZF|DA|PYG|LYP|J$|ISK|ESP|BMP|LD|LYB|Ber$|NLG|UM|RI|SKr|ERN|K Sh|CFF|Arg$|ARP|ARM|NT$|SDP|lari|GEK|MQF|FKP|ARA|SDD|ID|TVD|SR|LVR|FJP|LVL|CDL|CDG|CDF|F$|NIO|MOP|NIG|NIC|XTR|FIN|FIM|SI$|LUF|TTO|AOS|AOR|Tug|Ft|Fbu|AON|AOK|TT$|E|SAS|SRl|LTT|INR|PTE|AOA|PTC|LTL|T|KZR|VGD|NGP|MMX|NGN|HTG|LS|PSP|BD|MMK|NA f.|CZK|IMP|BGX|M|GAF|BGO|BGN|BGM|Can$|lev|TL|KYD|\u00a3C|ILS|G$|dram|ILP|MLF|ILL|Be|ALX|LRD|ALV|HRK|REF|HRD|lek|JEP|ALK|MKN|VDP|VDN|MDen|VDD|TPP|CFPF|BEL|GWP|KD|BF|TPE|BEC|GWE|SVC|CWG|Tk|TOS|T$|XOF|SUR|SUN|NCF|CVEsc|XNF|R|RD$|CUX|ZAP|ZAL|TND|CUP|USh|LNR|AIF|VAL|STE|UGS|Db|MHD|NZP|WST|WSP|L|XMF|TMM|Q|$NZ|SSP|BDS$|N$|MGF|MGA|EGP|BZH|PLZ|BAN|PLX|KM|BZ$|BAD|z\u0142|YRl|Sf|CSK|KRW|Rbl|YEI|BYL|CSC|KRO|KRH|BYB|SQS|GRN|Pra|Af|Z$|SL Re|GRD|IR\u00a3|AFA|YDD|RWF|C|TJS|TJR|EEK|GQP|MDR|HK$|DKr|MDL|GQF|GQE|Rp|AED|KPW|IDN|BWP|MDC|IDJ|KPP|IDG|VT|XID|So. Sh.|ADP|RUR|GPF|DF|ADD|MCG|MCF|ECS|LIF|RUB|PHP|UZS|Col$|THB|IBP|BUR|COF|BUK|COB|UZC|UAK|QR|UAH|GNS|Y|Mt|CNX|Ur$|GNI|SML|MZE|CNP|PGK|OMS|GF|UYP|RO|XFU|BTR|ZRZ|MAF|MAD|Nu|XFO|UYF|RM|ZRN|AZM|GMP|CF|SLL|GMD|BSP|CMF|XEF|BSD|MXP|MEX$|PES|GLK|BRZ|PEN|Ch$|Sk|PEI|BRR|XDR|FRF|BRN|CLE|R$|CLC|BRE|MWP|BRC|BRB|MK|PDR|DEM|TDF|PDN|PDK|Nrs|CKD|MVR|XCF|MVP|EC$|SIT|YUR|AWG|YUO|DDM|YUN|YUM|TCC|YUG|YUF|RON|YUD|leu|SIB|NKr|MUR|GIP|VNS|VNR|KID|SHP|VNN";

  private static final Hashtable currenciesSymbol;
  static
  {
    currenciesSymbol = new Hashtable();
    Enumeration keys = new StringTokenizer(currenciesSymbolKeys, "|");
    Enumeration values = new StringTokenizer(currenciesSymbolValues, "|");
    while (keys.hasMoreElements())
      {
         String key = (String) keys.nextElement();
         String value = (String) values.nextElement();
         currenciesSymbol.put(key, value);
      }
  }

  private static final String[] shortMonths = {
    "st",
    "lut",
    "mrz",
    "kw",
    "maj",
    "cz",
    "lip",
    "sier",
    "wrz",
    "pa\u017a",
    "lis",
    "gr",
    null,
  };

  private static final String[] months = {
    "Stycze\u0144",
    "Luty",
    "Marzec",
    "Kwiecie\u0144",
    "Maj",
    "Czerwiec",
    "Lipiec",
    "Sierpie\u0144",
    "Wrzesie\u0144",
    "Pa\u017adziernik",
    "Listopad",
    "Grudzie\u0144",
    null,
  };

  private static final String[] shortWeekdays = {
    null,
    "N",
    "Pn",
    "Wt",
    "\u015ar",
    "Cz",
    "Pt",
    "So",
  };

  private static final String[] weekdays = {
    null,
    "niedziela",
    "poniedzia\u0142ek",
    "wtorek",
    "\u015broda",
    "czwartek",
    "pi\u0105tek",
    "sobota",
  };

  private static final String[] eras = {
    "p.n.e.",
    "n.e.",
  };

  private static final String territoriesKeys = "TL|TK|TJ|TH|TG|TF|GY|TD|TC|GW|GU|GT|GS|GR|GQ|GP|SZ|SY|GN|GM|GL|SV|ST|GI|GH|SR|GF|SP|GE|SO|GD|SN|SM|GB|SL|GA|SK|SJ|SI|SH|SG|SE|SD|SC|SB|SA|FR|FO|FM|RW|FK|RU|FJ|FI|RO|RE|ET|ES|ER|EH|EG|EE|EC|DZ|QA|DO|PY|DM|PW|DK|DJ|PT|PS|PR|DE|PN|PM|PL|PK|PH|PG|PF|CZ|PE|CY|CX|CV|PA|CU|CR|CO|CN|CM|CL|CK|CI|CH|CG|CF|CD|CC|OM|CA|BZ|BY|BW|BV|BT|BS|BR|NZ|BO|BN|BM|NU|BJ|BI|BH|NR|BG|BF|NP|BE|NO|BD|BB|ZW|NL|BA|NI|NG|NF|AZ|NE|NC|AW|ZM|NA|AU|AT|AS|AR|AQ|MZ|AO|MY|AN|MX|AM|MW|AL|MV|ZA|MU|MT|AI|MS|MR|AG|MQ|AF|MP|AE|MO|AD|MN|MM|ML|MK|YU|YT|MH|MG|MD|MC|MA|YE|LY|LV|LU|LT|LS|LR|LK|LI|LC|LB|LA|KZ|KY|KW|KR|KP|KN|KM|KI|WS|KH|KG|KE|WF|JP|JO|JM|VU|VN|VI|VG|VE|VC|VA|IT|IS|IR|IQ|UZ|IO|UY|IN|IL|US|IE|ID|UM|UG|UA|HU|HT|HR|TZ|HN|HM|TW|TV|HK|TT|TR|TO|TN|TM";

  private static final String territoriesValues = "Timor Wschodni|Tokelau|Tad\u017cykistan|Tajlandia|Togo|Francuskie Terytoria Po\u0142udniowe|Gujana|Czad|Turks i Caicos|Gwinea Bissau|Guam|Gwatemala|Wyspy Georgia Po\u0142udniowa i Sandwich Po\u0142udniowy|Grecja|Gwinea R\u00f3wnikowa|Gwadelupa|Suazi|Syria|Gwinea|Gambia|Grenlandia|Salwador|Wyspy \u015awi\u0119tego Tomasza i Ksi\u0105\u017c\u0119ca|Gibraltar|Ghana|Surinam|Gujana Francuska|Serbia|Gruzja|Somalia|Grenada|Senegal|San Marino|Wielka Brytania|Sierra Leone|Gabon|S\u0142owacja|Svalbard i Wyspy Jan Mayen|S\u0142owenia|Wyspa \u015awi\u0119tej Heleny|Singapur|Szwecja|Sudan|Seszele|Wyspy Salomona|Arabia Saudyjska|Francja|Wyspy Owcze|Mikronezja, Stany Sfederowane|Rwanda|Falklandy (Malwiny)|Federacja Rosyjska|Fid\u017ci|Finlandia|Rumunia|Reunion|Etiopia|Hiszpania|Erytrea|Sahara Zachodnia|Egipt|Estonia|Ekwador|Algieria|Katar|Republika Dominika\u0144ska|Paragwaj|Dominika|Palau|Dania|D\u017cibuti|Portugalia|Terytoria Palesty\u0144skie|Puerto Rico|Niemcy|Pitcairn|St. Pierre i Miquelon|Polska|Pakistan|Filipiny|Papua Nowa Gwinea|Polinezja Francuska|Republika Czeska|Peru|Cypr|Wyspa Bo\u017cego Narodzenia|Wyspy Zielonego Przyl\u0105dka|Panama|Kuba|Kostaryka|Kolumbia|Chiny|Kamerun|Chile|Wyspy Cooka|Wybrze\u017ce Ko\u015bci S\u0142oniowej|Szwajcaria|Kongo|Republika \u015arodkowej Afryki|Kongo, Republika Demokratyczna|Wyspy Kokosowe (Keelinga)|Oman|Kanada|Belize|Bia\u0142oru\u015b|Botswana|Wyspa Bouveta|Bhutan|Bahamy|Brazylia|Nowa Zelandia|Boliwia|Brunei Darussalam|Bermudy|Niue|Benin|Burundi|Bahrajn|Nauru|Bu\u0142garia|Burkina Faso|Nepal|Belgia|Norwegia|Bangladesz|Barbados|Zimbabwe|Holandia|Bo\u015bnia i Hercegowina|Nikaragua|Nigeria|Wyspa Norfolk|Azerbejd\u017can|Niger|Nowa Kaledonia|Aruba|Zambia|Namibia|Australia|Austria|Samoa Ameryka\u0144skie|Argentyna|Antarktyka|Mozambik|Angola|Malezja|Antyle Holenderskie|Meksyk|Armenia|Malawi|Albania|Malediwy|Afryka Po\u0142udniowa|Mauritius|Malta|Anguilla|Montserrat|Mauretania|Antigua i Barbuda|Martynika|Afganistan|Wsp\u00f3lnota Marian\u00f3w P\u00f3\u0142nocnych|Zjednoczone Emiraty Arabskie|Makau, Specjalny Region Administracyjny Chin|Andora|Mongolia|Birma|Mali|Macedonia, Republika|Jugos\u0142awia|Majotta|Wyspy Marshalla|Madagaskar|Mo\u0142dawia, Republika|Monako|Maroko|Jemen|Libijska|\u0141otwa|Luksemburg|Litwa|Lesotho|Liberia|Sri Lanka|Liechtenstein|Saint Lucia|Liban|Laos (Demokratyczna Republika Ludowa)|Kazachstan|Kajmany|Kuwejt|Korea Po\u0142udniowa|Korea P\u00f3\u0142nocna|Saint Kitts i Nevis|Komory|Kiribati|Samoa|Kambod\u017ca|Kirgistan|Kenia|Wallis i Futuna|Japonia|Jordania|Jamajka|Vanuatu|Wietnam|Wyspy Dziewicze, Stan\u00f3w Zjednoczonych|Brytyjskie Wyspy Dziewicze|Wenezuela|Saint Vincent and the Grenadines|Stolica Apostolska (Pa\u0144stwo Watyka\u0144skie)|W\u0142ochy|Islandia|Iran|Irak|Uzbekistan|Terytorium Brytyjskie Oceanu Indyjskiego|Urugwaj|Indie|Izrael|Stany Zjednoczone|Irlandia|Indonezja|United States Minor Outlying Islands|Uganda|Ukraina|W\u0119gry|Haiti|Chorwacja|Tanzania|Honduras|Wyspy Heard i McDonald|Tajwan|Tuvalu|Hongkong, Specjalny Region Administracyjny Chin|Trinidad i Tobago|Turcja|Tonga|Tunezja|Turkmenia";

  private static final Hashtable territories;
  static
  {
    territories = new Hashtable();
    Enumeration keys = new StringTokenizer(territoriesKeys, "|");
    Enumeration values = new StringTokenizer(territoriesValues, "|");
    while (keys.hasMoreElements())
      {
         String key = (String) keys.nextElement();
         String value = (String) values.nextElement();
         territories.put(key, value);
      }
  }

  private static final String languagesKeys = "ja|en|tr|ko|no|el|nl|bg|lv|he|cs|it|lt|fr|zh|ru|ro|fi|ar|sv|pt|pl|sl|sk|de|hu|et|es|hr|da";

  private static final String languagesValues = "japo\u0144ski|angielski|turecki|korea\u0144ski|norweski|grecki|holenderski|bu\u0142garski|\u0142otewski|hebrajski|czeski|w\u0142oski|litewski|francuski|chi\u0144ski|rosyjski|rumu\u0144ski|fi\u0144ski|arabski|szwedzki|portugalski|polski|s\u0142owe\u0144ski|s\u0142owacki|niemiecki|w\u0119gierski|esto\u0144ski|hiszpa\u0144ski|chorwacki|du\u0144ski";

  private static final Hashtable languages;
  static
  {
    languages = new Hashtable();
    Enumeration keys = new StringTokenizer(languagesKeys, "|");
    Enumeration values = new StringTokenizer(languagesValues, "|");
    while (keys.hasMoreElements())
      {
         String key = (String) keys.nextElement();
         String value = (String) values.nextElement();
         languages.put(key, value);
      }
  }

  private static final Object[][] contents =
  {
    { "decimalSeparator", "," },
    { "groupingSeparator", "\u00a0" },
    { "currenciesDisplayName", currenciesDisplayName },
    { "currenciesSymbol", currenciesSymbol },
    { "shortMonths", shortMonths },
    { "months", months },
    { "shortWeekdays", shortWeekdays },
    { "weekdays", weekdays },
    { "eras", eras },
    { "shortDateFormat", "yy-MM-dd" },
    { "mediumDateFormat", "yyyy-MM-dd" },
    { "longDateFormat", "d MMMM yyyy" },
    { "fullDateFormat", "EEEE, d MMMM yyyy" },
    { "territories", territories },
    { "languages", languages },
  };

  public Object[][] getContents() { return contents; }
}
